@@ -47,6 +47,8 @@ class MongoBackend(BaseDictBackend):
     mongodb_taskmeta_collection = 'celery_taskmeta'
     mongodb_max_pool_size = 10
 
+    supports_autoexpire = False
+
     def __init__(self, *args, **kwargs):
         """Initialize MongoDB backend instance.
 
@@ -72,6 +74,7 @@ class MongoBackend(BaseDictBackend):
             self.mongodb_host = config.get('host', self.mongodb_host)
             self.mongodb_port = int(config.get('port', self.mongodb_port))
             self.mongodb_user = config.get('user', self.mongodb_user)
+            self.mongodb_options = config.get('options', {})
             self.mongodb_password = config.get(
                 'password', self.mongodb_password)
             self.mongodb_database = config.get(
@@ -100,7 +103,9 @@ class MongoBackend(BaseDictBackend):
                     and not self.mongodb_host.startswith('mongodb://'):
                 args.append(self.mongodb_port)
 
-            self._connection = Connection(*args, **kwargs)
+            self._connection = Connection(
+                *args, **dict(kwargs, self.mongodb_options)
+            )
 
         return self._connection
 
