@@ -13,7 +13,6 @@ import time
 
 from collections import deque
 from copy import copy
-from itertools import imap
 
 from kombu.utils import cached_property
 from kombu.utils.compat import OrderedDict
@@ -211,7 +210,7 @@ class AsyncResult(ResultBase):
         return self.__class__, self.__reduce_args__()
 
     def __reduce_args__(self):
-        return self.id, self.backend, self.task_name, self.parent
+        return self.id, self.backend, self.task_name, None, self.parent
 
     @cached_property
     def graph(self):
@@ -381,7 +380,7 @@ class ResultSet(ResultBase):
         :returns: the number of tasks completed.
 
         """
-        return sum(imap(int, (result.successful() for result in self.results)))
+        return sum(int(result.successful()) for result in self.results)
 
     def forget(self):
         """Forget about (and possible remove the result of) all the tasks."""
@@ -727,7 +726,7 @@ def from_serializable(r, app=None):
         if isinstance(r, (list, tuple)):
             id, nodes = r
             if nodes:
-                return app.GroupResult(id, [Result(id) for id, _ in nodes])
+                return app.GroupResult(id, [Result(sid) for sid, _ in nodes])
             return Result(id)
         else:
             return Result(r)
